@@ -2,7 +2,7 @@ use std::{
     collections::{HashMap, HashSet},
     fs,
     io::Write,
-    path::Path,
+    path::Path, time::Duration, thread,
 };
 
 use cargo::{
@@ -149,7 +149,7 @@ fn publish_crate(
         ) {
             Ok(_) => Ok(()),
             Err(e) => {
-                if current_try > 4 {
+                if current_try > 5{
                     panic!("ARMORY: failed to publish {} after {} attempts: {:#?}",
                             current_package, current_try, e);
                 } else {
@@ -162,5 +162,8 @@ fn publish_crate(
     })
     .unwrap();
 
+    // sleep for a bit to let the crates.io index catch up
+    thread::sleep(Duration::from_millis(2000));
+
     already_published.insert(current_package.to_string());
 }
